==> mule-devkit-annotations-3.7.2-sources.jar: org/mule/api/annotations/display/Placement.java <==
/**
 * Mule Development Kit
 * Copyright 2010-2012 (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 *
 * This software is protected under international copyright law. All use of this software is
 * subject to MuleSoft's Master Subscription Agreement (or other master license agreement)
 * separately entered into in writing between you and MuleSoft. If such an agreement is not
 * in place, you may not use the software.
 */


package org.mule.api.annotations.display;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Adds placement information to a field or parameter.
 */
@Target({ElementType.PARAMETER, ElementType.FIELD})
@Documented
@Retention(RetentionPolicy.SOURCE)
public @interface Placement {

    int DEFAULT_ORDER = 1;

    /**
     * Gives the annotated element a relative order within its {@link this#group()}. The value provided may be repeated
     * and in that case the order is not guaranteed.
     * The value is relative meaning that an element with order 10 has higher precence than one with value 25.
     */
    int order() default DEFAULT_ORDER;

    /**
     * A group is a logical way to display one or more variables together. If no group is specified then a
     * dafult group is assumed. To place more than one element in the same group, use the exact same values for
     * the this attribute
     */
    String group() default "";

    /**
     * A tab is a logical way to groups together. This attributes specifies the name of the tab in which the
     * annotated element should be displayed. If no tab is specified then a default tab is assumed. To display
     * more than one parameter or field in the same the tab then this value should be exactly the same for all of them.
     */
    String tab() default "";
}

==> mule-devkit-annotations-3.9.15-sources.jar: org/mule/api/annotations/display/Placement.java <==
/**
 * (c) 2003-2015 MuleSoft, Inc. This software is protected under international copyright
 * law. All use of this software is subject to MuleSoft's Master Subscription Agreement
 * (or other master license agreement) separately entered into in writing between you and
 * MuleSoft. If such an agreement is not in place, you may not use the software.
 */

package org.mule.api.annotations.display;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Defines the placement of a {@link org.mule.api.annotations.Configurable} field
 * or {@link org.mule.api.annotations.Connect} method parameter in the connector configuration window.
 *
 */
@Target({ElementType.PARAMETER, ElementType.FIELD})
@Documented
@Retention(RetentionPolicy.SOURCE)
public @interface Placement {

    int DEFAULT_ORDER = 1;

    /**
     * Gives the annotated element a relative order within its {@link this#group()}. The value provided may be repeated
     * and in that case the order is not guaranteed.
     * The value is relative meaning that an element with order 10 has higher precence than one with value 25.
     */
    int order() default DEFAULT_ORDER;

    /**
     * A group is a logical way to display one or more variables together. If no group is specified then a
     * default group is assumed. To place more than one element in the same group, use the exact same values for
     * this attribute
     */
    String group() default "";

    /**
     * A tab is a logical way to groups together. This attributes specifies the name of the tab in which the
     * annotated element should be displayed. If no tab is specified then a default tab is assumed. To display
     * more than one parameter or field in the same the tab then this value should be exactly the same for all of them.
     */
    String tab() default "";
}
